==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pt-BR/admin/custom_fields/message.php <==
<?php

return array(

    'field' => array(
        'invalid'   => 'Esse campo não existe.',
        'already_added'   => 'Campo já adicionado',

        'create' => array(
            'error'   => 'Campo não criado. Por favor tente novamente.',
            'success' => 'Campo criado com sucesso.',
            'assoc_success' => 'Campo adicionado ao conjunto de campos com sucesso.'
        ),

        'update' => array(
            'error'   => 'Campo não foi atualizado, por favor tente de novamente',
            'success' => 'Campo atualizado com sucesso.'
        ),

        'delete' => array(
            'confirm'   	=> 'Tem certeza que deseja excluir este campo?',
            'error'   => 'Ocorreu um erro ao remover o campo. Por favor tente novamente.',
            'success' => 'O campo foi apagado com sucesso.',
            'in_use'   => 'Campo continua em uso.',
        )

    ),

    'fieldset' => array(

        'does_not_exist' => 'Fieldset não existe',

        'create' => array(
            'error'   => 'O Conjunto de campos não foi criado, por favor tente novamente.',
            'success' => 'Conjunto de campos criado com sucesso.'
        ),

        'update' => array(
            'error'   => 'Conjunto de campos não foi atualizado, por favor tente novamente',
            'success' => 'Conjunto de campos atualizado com sucesso.'
        ),

        'delete' => array(
            'confirm'   	=> 'Tem a certeza que deseja eliminar este conjunto de campos?',
            'error'   => 'Ocorreu um erro ao apagar o conjunto de campos. Por favor tente novamente.',
            'success' => 'O campo foi apagado com sucesso.',
            'in_use'   => 'Conjunto de campos continua em uso.',
        )

    ),






);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/pt-BR/admin/custom_fields/message.php <==
<?php

return array(

    'field' => array(
        'invalid'   => 'Esse campo não existe.',
        'already_added'   => 'Campo já adicionado',
        'none_selected'   => 'No field selected',

        'create' => array(
            'error'   => 'Campo não criado. Por favor tente novamente.',
            'success' => 'Campo criado com sucesso.',
            'assoc_success' => 'Campo adicionado ao conjunto de campos com sucesso.'
        ),

        'update' => array(
            'error'   => 'Campo não foi atualizado, por favor tente de novamente',
            'success' => 'Campo atualizado com sucesso.'
        ),

        'delete' => array(
            'confirm'   	=> 'Tem certeza que deseja excluir este campo?',
            'error'   => 'Ocorreu um erro ao remover o campo. Por favor tente novamente.',
            'success' => 'O campo foi apagado com sucesso.',
            'in_use'   => 'Campo continua em uso.',
        )

    ),

    'fieldset' => array(

        'does_not_exist' => 'Fieldset não existe',

        'create' => array(
            'error'   => 'O Conjunto de campos não foi criado, por favor tente novamente.',
            'success' => 'Conjunto de campos criado com sucesso.'
        ),

        'update' => array(
            'error'   => 'Conjunto de campos não foi atualizado, por favor tente novamente',
            'success' => 'Conjunto de campos atualizado com sucesso.'
        ),

        'delete' => array(
            'confirm'   	=> 'Tem a certeza que deseja eliminar este conjunto de campos?',
            'error'   => 'Ocorreu um erro ao apagar o conjunto de campos. Por favor tente novamente.',
            'success' => 'O campo foi apagado com sucesso.',
            'in_use'   => 'Conjunto de campos continua em uso.',
        )

    ),

    'fieldset_default_value' => array(

        'error' => 'Erro ao validar valores padrão do campo.',

    ),






);
